@@ -12,6 +12,7 @@ Usage::
         DescribeJobDefinitionsPaginator,
         DescribeJobQueuesPaginator,
         ListJobsPaginator,
+        ListSchedulingPoliciesPaginator,
     )
 
     session = boto3.Session()
@@ -23,6 +24,7 @@ Usage::
     describe_job_definitions_paginator: DescribeJobDefinitionsPaginator = client.get_paginator("describe_job_definitions")
     describe_job_queues_paginator: DescribeJobQueuesPaginator = client.get_paginator("describe_job_queues")
     list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
+    list_scheduling_policies_paginator: ListSchedulingPoliciesPaginator = client.get_paginator("list_scheduling_policies")
     ```
 """
 from .client import BatchClient
@@ -31,6 +33,7 @@ from .paginator import (
     DescribeJobDefinitionsPaginator,
     DescribeJobQueuesPaginator,
     ListJobsPaginator,
+    ListSchedulingPoliciesPaginator,
 )
 
 Client = BatchClient
@@ -43,4 +46,5 @@ __all__ = (
     "DescribeJobDefinitionsPaginator",
     "DescribeJobQueuesPaginator",
     "ListJobsPaginator",
+    "ListSchedulingPoliciesPaginator",
 )
